#!/usr/bin/env python

import glob, os, sys

# The next statements assure importation of qwt from the
# local source tree. This is useful for debugging and testing.
globs = glob.glob('../build/lib.*/qwt')
if globs:                               # found PyQwt modules made by distutils
    sys.path.insert(0, os.path.split(globs[0])[0])

from qt import *
from qwt import *

__all__ = [
    'Curve',
    'Plot',
    'black',
    'blue',
    'cyan',
    'darkBlue',
    'darkCyan',
    'darkGray',
    'darkGreen',
    'darkMagenta',
    'darkRed',
    'darkYellow',
    'gray',
    'green',
    'lightGray',
    'magenta',
    'red',
    'white',
    'yellow',
    ]

black       = Qt.black
blue        = Qt.blue
cyan        = Qt.cyan
darkBlue    = Qt.darkBlue
darkCyan    = Qt.darkCyan
darkGray    = Qt.darkGray
darkGreen   = Qt.darkGreen
darkMagenta = Qt.darkMagenta
darkRed     = Qt.darkRed
darkYellow  = Qt.darkYellow
gray        = Qt.gray
green       = Qt.green
lightGray   = Qt.lightGray
magenta     = Qt.magenta
red         = Qt.red
white       = Qt.white
yellow      = Qt.yellow


# A class Curve in the following style looks nice to me
# so we can pass a list of those Curves to Plot

class Curve:
    def __init__(self, x=None, y=None, color=None, label=None):
        if x: # must be sequence of floats
            self.x = x
        if y: # must be sequence of floats
            self.y = y
        if color: # must be QColor
            self.color = color
        if label: # must be string
            self.label = label


class Plot(QwtPlot):
    """
    Plot offers a simplified user interface to QwtPlot.
    It recognizes the following keywords:
    curves   -> p = Plot(curves = [ Curves(x, y, color, label), ...])
    size     -> p = Plot(size=(800, 600))
    title    -> p = Plot(name='Any string')
    """
    def __init__(self, curves = None, size = None, title = None, *args):
        apply(QwtPlot.__init__, (self,) + args)
        self.setAutoLegend(1)
        self.setLegendPos(Qwt.Right)
        if size:
            apply(self.resize, size)
        else:
            self.resize(600, 400)
        if title:
            self.setTitle(title)
        if curves:
            for curve in curves:
                key = self.insertCurve(curve.label)
                self.setCurvePen(key, QPen(curve.color))
                self.setCurveData(key, curve.x, curve.y)
        self.replot()
        self.show()


if __name__ == '__main__':
    from Numeric import *
    a = QApplication(sys.argv)
    x = arange(-2*pi, 2*pi, 0.01)
    y1 = sin(x)
    y2 = cos(x)
    c1 = Curve(x, y1, red, "sin(x)")
    c2 = Curve(x, y2, blue, "cos(x)")
    p = Plot(title="Demo", curves=[c1, c2])
    a.setMainWidget(p)
    a.exec_loop()
    
